@@ -51,6 +51,7 @@ INTERNAL_USER_LOGIN = 'internal'
 INTERNAL_USER_ID = '{0}:{1}'.format(SYSTEM_PREFIX, INTERNAL_USER_LOGIN)
 
 SYSTEM_ADMIN_ROLE = 'system.Manager'
+SYSTEM_VIEWER_ROLE = 'system.Viewer'
 
 USER_LOGIN_TITLE = _("User login")
 
@@ -72,7 +73,7 @@ class RoleEvent(ObjectEvent):
     """Base role event"""
 
     def __init__(self, object, role_id, principal_id):  # pylint: disable=redefined-builtin
-        super(RoleEvent, self).__init__(object)
+        super().__init__(object)
         self.role_id = role_id
         self.principal_id = principal_id
 
@@ -247,6 +248,12 @@ class IGroupsAwareDirectoryPlugin(Interface):
 # User local registration
 #
 
+SALT_SIZE = {
+    'SSHA512': 32,
+    'PBKDF2': 32
+}
+
+
 class IUsersFolderPlugin(IAuthenticationPlugin, IDirectorySearchPlugin):
     """Local users folder interface"""
 
@@ -401,7 +408,7 @@ class ILocalUser(IAttributeAnnotatable):
                               description=_("Utility used to encrypt user password"),
                               required=True,
                               vocabulary=PASSWORD_MANAGERS_VOCABULARY_NAME,
-                              default='SSHA')
+                              default='PBKDF2')
 
     password = EncodedPasswordField(title=_("Password"),
                                     min_length=8,
